summaryrefslogtreecommitdiff
path: root/sources/utils
diff options
context:
space:
mode:
authorPaul Buetow <paul@buetow.org>2008-08-14 06:30:15 +0000
committerPaul Buetow <paul@buetow.org>2008-08-14 06:30:15 +0000
commit3a8c6531a45bc72842f92c68afc5cae1a7ed92a9 (patch)
treef7d5ea387871b2e1caa64ddeb01cad76b7bc101f /sources/utils
parent286a28082bbbe386c992ae0b098a1efcf2660376 (diff)
final
Diffstat (limited to 'sources/utils')
-rw-r--r--sources/utils/VS3Tupel.java (renamed from sources/utils/VSTupel.java)6
1 files changed, 3 insertions, 3 deletions
diff --git a/sources/utils/VSTupel.java b/sources/utils/VS3Tupel.java
index 87bd825..4d4c896 100644
--- a/sources/utils/VSTupel.java
+++ b/sources/utils/VS3Tupel.java
@@ -24,12 +24,12 @@
package utils;
/**
* The class VSTupel, an object of this class represents a 3-Tupel of objects.
* Each object can have its own type.
*
* @author Paul C. Buetow
*/
-public final class VSTupel<A,B,C> {
+public final class VS3Tupel<A,B,C> {
/** The serial version uid */
private static final long serialVersionUID = 1L;
@@ -49,7 +49,7 @@ public final class VSTupel<A,B,C> {
* @param b the b
* @param c the c
*/
- public VSTupel(A a, B b, C c) {
+ public VS3Tupel(A a, B b, C c) {
this.a = a;
this.b = b;
this.c = c;
@@ -24,12 +24,12 @@
package utils;
/**
- * The class VSTupel, an object of this class represents a 3-Tupel of objects.
+ * The class VS3Tupel, an object of this class represents a 3-Tupel of objects.
* Each object can have its own type.
*